pub enum VerKeyCode {
Ed25519,
Ed25519N,
ECDSA256k1,
ECDSA256k1N,
Ed448,
Ed448N,
ECDSA256r1,
ECDSA256r1N,
}Available on crate feature
core only.Expand description
CESR codes for verification (public) keys, both transferable and non-transferable.
Variants
Ed25519
Ed25519 transferable (rotatable) public key.
Ed25519N
Ed25519 non-transferable (non-rotatable) public key.
ECDSA256k1
secp256k1 (ECDSA) transferable compressed public key.
ECDSA256k1N
secp256k1 (ECDSA) non-transferable compressed public key.
Ed448
Ed448 transferable public key.
Ed448N
Ed448 non-transferable public key.
ECDSA256r1
secp256r1 / P-256 (ECDSA) transferable compressed public key.
ECDSA256r1N
secp256r1 / P-256 (ECDSA) non-transferable compressed public key.
Implementations
Sourceimpl VerKeyCode
impl VerKeyCode
Sourcepub const fn is_transferable(&self) -> bool
pub const fn is_transferable(&self) -> bool
Returns true if this key can be rotated (transferable prefix).
Sourcepub const fn is_non_transferable(&self) -> bool
pub const fn is_non_transferable(&self) -> bool
Returns true if this key cannot be rotated (non-transferable prefix).